Datasets
---------

Structure datasets
^^^^^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.datasets.core_dataset
    :members:


.. automodule:: mofdscribe.datasets.qmof_dataset
    :members:


.. automodule:: mofdscribe.datasets.bw_dataset
    :members:


.. automodule:: mofdscribe.datasets.arabg_dataset
    :members:


.. automodule:: mofdscribe.datasets.arcmof_dataset
    :members:


.. automodule:: mofdscribe.datasets.thermal_stability_dataset
    :members:


.. automodule:: mofdscribe.datasets.structuredataset
    :members: